@@ -1,11 +1,8 @@
-/***************************************************************************
- *   Copyright (C) 2006 by Matthew Williams    <matt@milliams.com>         *
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2006 Matthew Williams <matt@milliams.com>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include <KAboutData>
 #include <KCrash>
@@ -22,8 +19,6 @@
 #include "settings.h"
 #include "ksquares_version.h"
 
-static const char description[] =
-    I18N_NOOP("Take it in turns to draw lines.\nIf you complete a squares, you get another go.");
 
 int main(int argc, char **argv)
 {
@@ -36,7 +31,9 @@ int main(int argc, char **argv)
     migrate.setUiFiles(QStringList() << QStringLiteral("ksquaresui.rc"));
     migrate.migrate();
     KLocalizedString::setApplicationDomain("ksquares");
-    KAboutData about(QStringLiteral("ksquares"), i18n("KSquares"), QStringLiteral(KSQUARES_VERSION_STRING), i18n(description),
+    KAboutData about(QStringLiteral("ksquares"), i18n("KSquares"),
+                     QStringLiteral(KSQUARES_VERSION_STRING),
+                     i18n("Take it in turns to draw lines.\nIf you complete a squares, you get another go."),
                      KAboutLicense::GPL, i18n("(C) 2006-2007 Matt Williams"));
     about.addAuthor(i18n("Matt Williams"), i18n("Original creator and maintainer"), QStringLiteral("matt@milliams.com"), QStringLiteral("https://milliams.com"));
     about.addCredit(i18n("Fela Winkelmolen"), i18n("Many patches and bugfixes"));
